@@ -26,7 +26,7 @@ eval "use Devel::GlobalDestruction";
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(@ALL_JOBS %ALL_JOBS);
-our $VERSION = '0.73';
+our $VERSION = '0.74';
 
 our (@ALL_JOBS, %ALL_JOBS, @ARCHIVED_JOBS, $WIN32_PROC, $WIN32_PROC_PID);
 our $OVERLOAD_ENABLED = 0;
@@ -921,8 +921,19 @@ sub _postlaunch_child_to_cmd {
 
     } else {
 
+        my $retries = $job->{retries} || 0;
 	my $this_pid = $$;
 	my $exec_pid = _CORE_fork();
+	while (!defined $exec_pid && $retries-- > 0) {
+            warn "Forks::Super::Job::_postlaunch_child_to_cmd: ",
+                "system fork call returned undef. Retrying ...\n";
+            Forks::Super::Util::pause(1.0);
+            $exec_pid = _CORE_fork();
+        }
+        if (!defined $exec_pid) {
+            croak "Forks::Super::Job::_postlaunch_child_to_cmd: ",
+                "Child process unable to create new fork to run cmd";
+        }
 	if ($$ != $this_pid) {
 	    exec( @{$job->{cmd}} )
 		or Carp::confess 'exec for cmd-style fork failed ';
@@ -1864,6 +1875,19 @@ sub count_alive_processes {
     return scalar @alive;
 }
 
+sub count_queued_processes {
+    my ($count_bg,$optional_pgid) = @_;
+    my @deferred = grep { $_->{state} eq 'DEFERRED' ||
+                          $_->{state} eq 'SUSPENDED-DEFERRED' } @ALL_JOBS;
+    if (!$count_bg) {
+        @deferred = grep { $_->{_is_bg} == 0 } @deferred;
+    }
+    if (defined $optional_pgid) {
+        @deferred = grep { $_->{pgid} == $optional_pgid } @deferred;
+    }
+    return scalar @deferred;
+}
+
 #
 # _reap should distinguish:
 #
@@ -2010,7 +2034,7 @@ Forks::Super::Job - object representing a background task
 
 =head1 VERSION
 
-0.73
+0.74
 
 =head1 SYNOPSIS
 
@@ -2152,7 +2176,9 @@ resources but my tie up memory resources.
 =item C<SUSPENDED-DEFERRED>
 
 Job is in the job queue and has not started yet, and also
-the job has been suspended.
+the job has been suspended. A job in the C<SUSPENDED-DEFERRED>
+state can only move out of this state to the C<SUSPENDED> state
+(with a C<SIGCONT> or a L<"resume"|resume> call).
 
 =back
 
@@ -2296,6 +2322,16 @@ external command.
 
 =back
 
+=head3 count_queued_processes
+
+=over 4
+
+=item C< $n = Forks::Super::Job::count_queued_processes() >
+
+Returns the current number of inactive tasks in the job queue.
+
+=back
+
 =head1 METHODS
 
 A C<Forks::Super::Job> object recognizes the following methods.
@@ -2807,7 +2843,7 @@ Marty O'Brien, E<lt>mob@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009-2013, Marty O'Brien.
+Copyright (c) 2009-2015, Marty O'Brien.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself, either Perl version 5.8.8 or,
