@@ -33,13 +33,13 @@ $| = 1;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(close_fh);
-our $VERSION = '0.73';
+our $VERSION = '0.74';
 
 our (%FILENO, %SIG_OLD, $IPC_COUNT, $IPC_DIR_DEDICATED,
      @IPC_FILES, %IPC_FILES);
 our ($SIGNALS_TRAPPED, $_CLEANUP, $_SIGNAL_TRAPPED_SO_SUPPRESS_INFO) = (0,0,0);
 our $MAIN_PID = $$;
-our $__OPEN_FH = 0; # for debugging, monitoring filehandle usage. Not ready.
+our $__OPEN_FH = 0; # for debugging, monitoring file handle usage. Not ready.
 our $__MAX_OPEN_FH = do {
     no warnings 'once';
     $Forks::Super::SysInfo::MAX_OPEN_FH;
@@ -111,9 +111,9 @@ my $cleanse_mode = 0;
     }
 }
 
-# open a filehandle with (a little) protection
-# against "Too many open filehandles" error.
-# If supported, new filehandles are tied to
+# open a file handle with (a little) protection
+# against "Too many open files" error.
+# If supported, new file handles are tied to
 # F::S::Tie::IPCFileHandle, which (potentially)
 # logs and debugs activity on that handle.
 sub _safeopen ($*$$;%) {
@@ -150,7 +150,7 @@ sub _safeopen ($*$$;%) {
     }
 
     if ($__OPEN_FH > 0.98 * $__MAX_OPEN_FH) {
-	carp sprintf "This program now using %d of ~%d open file handles. Consider closing unused filehandles.", $__OPEN_FH, $__MAX_OPEN_FH;
+	carp sprintf "This program now using %d of ~%d open file handles. Consider closing unused file handles.", $__OPEN_FH, $__MAX_OPEN_FH;
 	$Forks::Super::Job::Ipc::TOO_MANY_OPEN_FH_WARNINGS++;
 
 	try_to_close_some_open_filehandles();
@@ -281,7 +281,7 @@ sub _handle_safeopen_failure {
     my ($try, $robust, $debug, $description) = @_;
     # called when _safeopen (_safeopen_open) returns false.
 
-    if ($! =~ /too many open filehandles/i ||
+    if ($! =~ /too many open file/i ||
 	$! == $Forks::Super::SysInfo::TOO_MANY_FH_ERRNO) {
 
 	carp "$! while opening $description. ",
@@ -307,14 +307,14 @@ sub try_to_close_some_open_filehandles {
     return if 'rescue' ne $Forks::Super::ON_TOO_MANY_OPEN_FILEHANDLES;
     my $nclosed = 0;
 
-    # in the child, you can close filehandles from unrelated jobs ...
+    # in the child, you can close file handles from unrelated jobs ...
     if ($$ != $Forks::Super::MAIN_PID) {
 	use POSIX ();
-	POSIX::close($_) for 3 .. 1000;
+	POSIX::close($_) for 3 .. 1000; # XXX
 	return;
     }
 
-    # where are the open filehandles, and which ones should we close?
+    # where are the open file handles, and which ones should we close?
     my @open_handles = ();
     foreach my $handle (@SAFEOPENED) {
 	if (ref $handle eq 'ARRAY') {
@@ -363,7 +363,7 @@ sub try_to_close_some_open_filehandles {
     #    * done (have a status)
 
     if ($nclosed) {
-	warn "Forks::Super::Job::Ipc: Closed $nclosed open filehandles from jobs that look complete.\n";
+	warn "Forks::Super::Job::Ipc: Closed $nclosed open file handles from jobs that look complete.\n";
 	$__OPEN_FH -= $nclosed;
     }
 
@@ -722,7 +722,7 @@ sub _preconfig_fh_sockets {
     if (!Forks::Super::Config::CONFIG('Socket')) {
 	carp 'Forks::Super::Job::_preconfig_fh_sockets(): ',
 	    'Socket unavailable. ',
-	    "Will try to use regular filehandles for child ipc.\n";
+	    "Will try to use regular file handles for child ipc.\n";
 	delete $config->{sockets};
 	return;
     }
@@ -752,7 +752,7 @@ sub _preconfig_fh_pipes {
     if (!$Forks::Super::SysInfo::CONFIG{'pipe'}) {
 	carp 'Forks::Super::Job::_preconfig_fh_pipes(): ',
 	    'Pipes unavailable. ',
-	    "Will try to use regular filehandles for child ipc.\n";
+	    "Will try to use regular file handles for child ipc.\n";
 	delete $config->{pipes};
 	return;
     }
@@ -955,10 +955,10 @@ sub _identify_shared_fh_dir {
 
     foreach my $dir (@search_dirs) {
 	next if !(defined($dir) && $dir =~ /\S/);
-	debug("Considering $dir as shared filehandle dir ...") if $DEBUG;
+	debug("Considering $dir as shared file handle dir ...") if $DEBUG;
 	if (Forks::Super::Config::configif('filehandles')) {
 	    if (set_ipc_dir($dir,0)) {
-		debug("Selected $_IPC_DIR as shared filehandle dir ...")
+		debug("Selected $_IPC_DIR as shared file handle dir ...")
 		    if $DEBUG;
 		return $_IPC_DIR;
 	    }
@@ -1347,13 +1347,13 @@ sub _END_background_cleanup2 {
 
     if (!$z
 	&& -d $_IPC_DIR
-	&& 0 < glob("$_IPC_DIR/.nfs*")) {
+	&& glob("$_IPC_DIR/.nfs*")) {
 
 	# Observed these files on Linux running from NSF mounted filesystem
 	# .nfsXXX files are usually temporary (~30s) but hard to kill
 	for my $i (1..10) {
 	    sleep 5;
-	    last if glob("$_IPC_DIR/.nfs*") <= 0;
+	    last unless glob("$_IPC_DIR/.nfs*");
 	}
 	$z = rmdir($_IPC_DIR) || 0;
     }
@@ -1536,7 +1536,8 @@ sub __config_fh_parent_stdin_pipes {
     my $fh_config = $job->{fh_config};
     if ($USE_TIE_PH) {
 	my $ph = _gensym();
-	tie *$ph, 'Forks::Super::Tie::IPCPipeHandle', $fh_config->{p_to_in}, $ph;
+	tie *$ph, 'Forks::Super::Tie::IPCPipeHandle',
+                $fh_config->{p_to_in}, $ph;
 	$job->{child_stdin}
 	    = $Forks::Super::CHILD_STDIN{$job->{real_pid}}
 	    = $Forks::Super::CHILD_STDIN{$job->{pid}}
@@ -1571,13 +1572,12 @@ sub __config_fh_parent_stdin_file {
 	$Forks::Super::CHILD_STDIN{$job->{pid}} = $fh;
 	$fh->autoflush(1);
 
-#    debug("Setting up link to $job->{pid} stdin in $fh_config->{f_in}")
-#	  if $job->{debug};
-	debug('Opened child STDIN (',fileno($fh),') in parent') if $job->{debug};
+        debug('Opened child STDIN (',fileno($fh),') in parent')
+            if $job->{debug};
 
     } else {
 	warn 'Forks::Super::Job::config_fh_parent(): ',
-		  'could not open filehandle to write child STDIN (to ',
+		  'could not open file handle to write child STDIN (to ',
 		  $fh_config->{f_in}, "): $!\n";
     }
     return;
@@ -1683,7 +1683,7 @@ sub _config_fh_parent_stress {
 	    	$$, Forks::Super::Util::Ctime(), $n, $fh_config->{$fkey}, $!;
 
 	    warn 'Forks::Super::Job::config_fh_parent(): ',
-	        'could not open filehandle to read child STDOUT (from ',
+	        'could not open file handle to read child STDOUT (from ',
 	    $fh_config->{$fkey}, "): $!\n";
 	}
     }
@@ -1703,7 +1703,8 @@ sub __config_fh_parent_stdout_file {
 
     if (_safeopen($job, $fh, '<', $fh_config->{f_out}, robust => 1)) {
 
-	debug('Opened child STDOUT (',fileno($fh),') in parent') if $job->{debug};
+	debug('Opened child STDOUT (',fileno($fh),') in parent')
+            if $job->{debug};
 	$job->{child_stdout} = $Forks::Super::CHILD_STDOUT{$job->{real_pid}}
 		= $Forks::Super::CHILD_STDOUT{$job->{pid}} = $fh;
 
@@ -1715,7 +1716,7 @@ sub __config_fh_parent_stdout_file {
 		$$, Forks::Super::Util::Ctime(), $fh_config->{f_out}, $!;
 
 	warn 'Forks::Super::Job::config_fh_parent(): ',
-	  'could not open filehandle to read child STDOUT (from ',
+	  'could not open file handle to read child STDOUT (from ',
 	  $fh_config->{f_out}, "): $!\n";
     }
     return;
@@ -1810,7 +1811,8 @@ sub __config_fh_parent_stderr_file {
     local $! = 0;
     if (_safeopen($job, $fh, '<', $fh_config->{f_err}, robust => 1)) {
 
-	debug('Opened child STDERR (',fileno($fh),') in parent') if $job->{debug};
+	debug('Opened child STDERR (',fileno($fh),') in parent')
+            if $job->{debug};
 	$job->{child_stderr}
 		= $Forks::Super::CHILD_STDERR{$job->{real_pid}}
 		= $Forks::Super::CHILD_STDERR{$job->{pid}}
@@ -1823,14 +1825,14 @@ sub __config_fh_parent_stderr_file {
 	my $_msg = sprintf "%d: %s Failed to open f_err=%s: %s\n",
 		$$, Forks::Super::Util::Ctime(), $fh_config->{f_err}, $!;
 	warn 'Forks::Super::Job::config_fh_parent(): ',
-	  'could not open filehandle to read child STDERR (from ',
+	  'could not open file handle to read child STDERR (from ',
 	  $fh_config->{f_err}, "): $!\n";
     }
     return;
 }
 
 #
-# open filehandles to the STDIN, STDOUT, STDERR processes of the job
+# open file handles to the STDIN, STDOUT, STDERR processes of the job
 # to be used by the parent. Presumably the child process is opening
 # the same files at about the same time.
 #
@@ -2003,7 +2005,7 @@ sub __config_fh_child_stdin_file {
 	    _safeopen($job, *STDIN, '<&', $fh, robust => 1)
 		or warn 'Forks::Super::Job::config_fh_child(): ',
 	    	        'could not attach child STDIN ',
-		        "to input filehandle: $!\n";
+		        "to input file handle: $!\n";
 	} else {
 	    # require Forks::Super::Tie::IPCDupSTDIN;
 	    tie *STDIN, 'Forks::Super::Tie::IPCDupSTDIN', 
@@ -2016,7 +2018,7 @@ sub __config_fh_child_stdin_file {
 	}
     } else {
 	warn 'Forks::Super::Job::config_fh_child(): ',
-		"could not open filehandle to provide child STDIN: $!\n";
+		"could not open file handle to provide child STDIN: $!\n";
     }
     return;
 }
@@ -2088,7 +2090,8 @@ sub __config_fh_child_stdout_pipes {
     close STDOUT;
     if ($USE_TIE_PH) {
 	my $fh = _gensym();
-	tie *$fh, 'Forks::Super::Tie::IPCPipeHandle', $fh_config->{p_to_out}, $fh;
+	tie *$fh, 'Forks::Super::Tie::IPCPipeHandle',
+                $fh_config->{p_to_out}, $fh;
 	*STDOUT = *$fh;
 	${*STDOUT}->{std_delegate} = $fh;
     } else {
@@ -2132,16 +2135,16 @@ sub __config_fh_child_stdout_file {
 		close STDERR if &IS_WIN32;
 		_safeopen($job, *STDERR, '>&', $fh)
 		    or warn 'Forks::Super::Job::config_fh_child(): ',
-		        "could not attach STDERR to child output filehandle: ",
+		        "could not attach STDERR to child output file handle: ",
 		        "$!\n";
 	    }
 	} else {
 	    warn 'Forks::Super::Job::config_fh_child(): ',
-	        "could not attach STDOUT to child output filehandle: $!\n";
+	        "could not attach STDOUT to child output file handle: $!\n";
 	}
     } else {
 	warn 'Forks::Super::Job::config_fh_child(): ',
-	    "could not open filehandle to provide child STDOUT: $!\n";
+	    "could not open file handle to provide child STDOUT: $!\n";
     }
     return;
 }
@@ -2246,10 +2249,10 @@ sub __config_fh_child_stderr_file {
 	close STDERR if &IS_WIN32;
 	_safeopen($job, *STDERR, '>&', $fh)
 	    or warn 'Forks::Super::Job::_config_fh_child_stderr(): ',
-		    "could not attach STDERR to child error filehandle: $!\n";
+		    "could not attach STDERR to child error file handle: $!\n";
     } else {
 	warn 'Forks::Super::Job::_config_fh_child_stderr(): ',
-		"could not open filehandle to provide child STDERR: $!\n";
+		"could not open file handle to provide child STDERR: $!\n";
     }
 
     return;
@@ -2258,7 +2261,7 @@ sub __config_fh_child_stderr_file {
 #
 # open handles to the files that the parent process will
 # have access to, and assign them to the local STDIN, STDOUT,
-# and STDERR filehandles.
+# and STDERR file handles.
 #
 sub Forks::Super::Job::_config_fh_child {
     my $job = shift;
@@ -2457,7 +2460,7 @@ sub _close {
 	# opened by Forks::Super
 	if (1 || $DEBUG) {
 	    Carp::cluck 'Forks::Super::Job::Ipc::_close ',
-	    "called on unrecognized filehandle $handle\n";
+	    "called on unrecognized file handle $handle\n";
 	}
     }
 
@@ -2711,7 +2714,7 @@ sub _read_socket {
 		      "[shouldn't reach this block]");
 	    }
 	    if ($nfound == -1) {
-		next if $!{EINTR}; # interrupted system call -- this is usually ok.
+		next if $!{EINTR}; # interrupted system call -- usually ok.
 		warn "Forks::Super:_read_socket: Error in select4(): $! $^E.\n";
 	    }
 	    last;
@@ -3057,16 +3060,16 @@ sub _unbuffered_getc {
 
 #
 # called from the parent process,
-# attempts to read a line from standard output filehandle
+# attempts to read a line from standard output file handle
 # of the specified child.
 #
 # returns "" if the process is running but there is no
-# output waiting on the filehandle
+# output waiting on the file handle
 #
 # returns undef if the process has completed and there is
-# no output waiting on the filehandle
+# no output waiting on the file handle
 #
-# performs trivial seek on filehandle before reading.
+# performs trivial seek on file handle before reading.
 # this will reduce performance but will always clear
 # error condition and eof condition on handle
 #
@@ -3081,7 +3084,7 @@ sub _readline {
 	return _read_pipe($fh,$job,$wantarray,%options);
     }
 
-    # WARNING: blocking read on a filehandle can lead to deadlock
+    # WARNING: blocking read on a file handle can lead to deadlock
     my ($expire, $blocking_desired) = __extract_read_options($fh, \%options);
 
     local $! = undef;
@@ -3095,7 +3098,8 @@ sub _readline {
 sub __sanitize_read_inputs {
     my ($fh, $job, $wantarray, %options) = @_;
     if (!defined $fh) {
-	if ($job->{debug} && (!defined($options{'warn'}) || $options{'warn'})) {
+	if ( $job->{debug} &&
+             (!defined($options{'warn'}) || $options{'warn'}) ) {
 	    carp 'Forks::Super::_readline(): ',
 	        "read on unconfigured handle for job $job->{pid}\n";
 	}
@@ -3205,6 +3209,7 @@ sub _readline_scalar {
 	if (!$blocking_desired) {
 	    if (!$job->{is_child}) {
 		# in the parent, we can tell the difference between this input
+
 		# stream being empty because the child process is finished
 		# (see _check_if_job_is_complete_and_close_io() call, above),
 		# and the stream being empty because the child isn't producing
@@ -3255,7 +3260,7 @@ sub deinit_child {
 
     if (@IPC_FILES > 0) {
         Carp::cluck("Child $$ had temp files! @IPC_FILES\n")
-	    if $Forks::Super::CHILD_FORK_OK < 0; # SO.com/questions/15230850
+	    if $Forks::Super::CHILD_FORK_OK < 0; # stackoverflow/q/15230850
 	unlink @IPC_FILES;
 	@IPC_FILES = ();
     }
