@@ -14,7 +14,7 @@ use strict;
 use warnings;
 require Forks::Super::Job::OS::Win32 if &IS_WIN32 || &IS_CYGWIN;
 
-our $VERSION = '0.73';
+our $VERSION = '0.74';
 
 our $CPU_AFFINITY_CALLS = 0;
 our $OS_PRIORITY_CALLS = 0;
@@ -331,7 +331,7 @@ sub poor_mans_alarm {
 	# don't want to run in a separate process to kill a thread.
 	if (CORE::fork() == 0) {
 	    $0 = "PMA[2]($pid,$time)";
-	    sleep 1, kill(0,$pid) || exit for 1..$time;
+	    sleep(1), kill(0,$pid) || exit for 1..$time;
 	    kill -9, $pid;
 	    exit;
 	}
