@@ -11,18 +11,36 @@ use warnings;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(bg_eval bg_qx BG_EVAL BG_QX);
-our $VERSION = '0.73';
+our $VERSION = '0.74';
 
 use constant BG_EVAL => 'Forks::Super::bg_eval';
 use constant BG_QX   => 'Forks::Super::bg_qx';
 
 sub _choose_protocol {
+    my %options = @_;
+    my $preference = $options{protocol} || $ENV{FORKS_SUPER_LAZYEVAL_PROTO};
+    if ($preference) {
+        if ($preference eq 'YAML' || $preference eq 'YAML::Tiny' || 
+            $preference eq 'Data::Dumper') {
+            if (CONFIG_module($preference)) {
+                return $preference;
+            } elsif ($options{protocol}) {
+                carp "bg_eval: bad protocol '$preference' supplied";
+            } else {
+                carp "bg_eval: bad protocol '$preference' in "
+                    . "\$ENV{FORKS_SUPER_LAZYEVAL_PROTO}";
+            }
+        } elsif ($options{protocol}) {
+            carp "bg_eval: bad protocol '$preference' supplied";
+        } else {
+            carp "bg_eval: bad protocol '$preference' in "
+                . "\$ENV{FORKS_SUPER_LAZYEVAL_PROTO}";
+        }
+    }
+
     if (CONFIG_module('YAML')) {
 	return 'YAML';
     }
-    if (CONFIG_module('JSON')) {
-	return $JSON::VERSION >= 2.0 ? 'JSON2' : 'JSON1';
-    }
     if (CONFIG_module('YAML::Tiny')) {
 	return 'YAML::Tiny';
     }
@@ -47,11 +65,11 @@ sub _options {
 
 sub bg_eval (&;@) {
     my ($code, @other_options) = @_;
-    my $proto = _choose_protocol();
+    my %other_options = _options(@other_options);
+    my $proto = _choose_protocol(%other_options);
     if (!defined $proto) {
 	croak "Forks::Super: bg_eval call requires either YAML or JSON\n";
     }
-    my %other_options = _options(@other_options);
 
     if (defined($other_options{daemon}) && $other_options{daemon}) {
 	croak 'Forks::Super::bg_eval: ',
@@ -319,7 +337,7 @@ Forks::Super::LazyEval
 
 =head1 VERSION
 
-0.73
+0.74
 
 =head1 DESCRIPTION
 
@@ -336,7 +354,7 @@ Marty O'Brien, E<lt>mob@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2010-2013, Marty O'Brien.
+Copyright (c) 2010-2015, Marty O'Brien.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
