@@ -8,6 +8,7 @@
 package Forks::Super::LazyEval::BackgroundScalar;
 use Forks::Super;
 use Forks::Super::Wait 'WREAP_BG_OK';
+use Scalar::Util 'reftype';
 use Carp;
 use strict;
 use warnings;
@@ -41,7 +42,8 @@ use overload # XXX - what is overloading for? is it necessary?
 
     # when we define %{} and internally require an element of an object,
     # we must unbless the object before the operation and rebless it
-    # afterward. See http://search.cpan.org/perldoc?overload#Two-face_references
+    # afterward. See search.cpan.org/perldoc?overload#Two-face_references
+
 
     '%{}' => sub { $_[0]->_fetch },
 
@@ -56,7 +58,7 @@ use overload # XXX - what is overloading for? is it necessary?
 		         : atan2($_[0]->_fetch, $_[1]) }
 ;
 
-our $VERSION = '0.73';
+our $VERSION = '0.74';
 
 # "protocols" for serializing data and the methods used
 # to carry out the serialization
@@ -75,7 +77,10 @@ my %serialization_dispatch = (
 	    my $data = shift;
 	    if (ref $data eq '') {
 		$data = "$data";
-	    }
+	    } elsif (ref($data) ne reftype($data)) {
+                croak "bg_eval: cannot use JSON to serialize "
+                    . "return value of type ", ref($data);
+            }
 	    return JSON->new->objToJson([$data]);
 	},
 	decode => sub { return JSON->new->jsonToObj($_[0])->[0] }
@@ -87,6 +92,9 @@ my %serialization_dispatch = (
 	    my $data = shift;
 	    if (ref $data eq '') {
 		$data = "$data";
+	    } elsif (ref($data) ne reftype($data)) {
+                croak "bg_eval: cannot use JSON to serialize "
+                    . "return value of type ", ref($data);
 	    }
 	    return JSON::encode_json([$data]);
 	},
@@ -140,7 +148,7 @@ sub new {
 		 my $Result = $command_or_code->();
 		 print STDOUT _encode($protocol, $Result);
 	     }, 
-	     _is_bg => 1, 
+	     _is_bg => 1,
 	     _lazy_proto => $protocol )
 	};
 
@@ -151,7 +159,7 @@ sub new {
 	    (%other_options, 
 	     child_fh => 'out',
 	     cmd => $command_or_code,
-	     stdout => \$self->{stdout}, 
+	     stdout => \$self->{stdout},
 	     _is_bg => 1)
 	};
     }
@@ -159,6 +167,12 @@ sub new {
     ($Forks::Super::LAST_JOB, $Forks::Super::LAST_JOB_ID)
 	= ($self->{job}, $self->{job_id});
     $self->{value} = undef;
+#    if ($other_options{blessed}) {
+#        if ($style eq 'qx') {
+#            croak "bg_qx: \"blessed\" option not supported";
+#        }
+##       $class = 'Forks::Super::LazyEval::BackgroundScalar::Blessed';
+#    }
     return bless $self, $class;
 }
 
@@ -262,6 +276,19 @@ sub _fetch {
     return $value;
 }
 
+sub Forks::Super::LazyEval::BackgroundScalar::AUTOLOAD {
+    my $obj = shift->_fetch;
+    my $ref = ref($obj);
+    my $method = $Forks::Super::LazyEval::BackgroundScalar::AUTOLOAD;
+    return if $method =~ /::DESTROY$/;
+    if (!$ref || $ref eq 'ARRAY' || $ref eq 'SCALAR' || $ref eq 'HASH') {
+        die "bg_eval: Can't call method '$method' on unblessed reference";
+    }
+    $method =~ s/.*:://;
+    no strict 'refs';
+    return $obj->$method(@_);
+}
+
 1;
 
 =head1 NAME
@@ -270,7 +297,7 @@ Forks::Super::LazyEval::BackgroundScalar
 
 =head1 VERSION
 
-0.73
+0.74
 
 =head1 DESCRIPTION
 
@@ -285,7 +312,7 @@ Marty O'Brien, E<lt>mob@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2010-2013, Marty O'Brien.
+Copyright (c) 2010-2015, Marty O'Brien.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
