@@ -21,7 +21,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(wait waitpid waitall TIMEOUT WREAP_BG_OK);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.73';
+our $VERSION = '0.74';
 
 my ($productive_waitpid_code);
 my $respect_SIGCHLD_ignore = 1;
@@ -127,21 +127,25 @@ sub waitpid {
     return _bogus_waitpid_result();
 }
 
-sub waitall {
-    my $timeout = shift || &FOREVER;
-    if ($timeout < 0) {
-	$timeout = &_BRIEF_TIMEOUT;
-    }
+sub reapall {
     my $waited_for = 0;
-    my $expire = Time::HiRes::time() + $timeout ;
-    debug('waitall: waiting on all procs') if $DEBUG;
-
     foreach my $job (@Forks::Super::Job::ALL_JOBS) {
 	if ($job->state eq 'COMPLETE') {
 	    $job->_mark_reaped;
 	    ++$waited_for;
 	}
     }
+    return $waited_for;
+}
+
+sub waitall {
+    my $timeout = shift || &FOREVER;
+    if ($timeout < 0) {
+	$timeout = &_BRIEF_TIMEOUT;
+    }
+    my $expire = Time::HiRes::time() + $timeout ;
+    debug('waitall: waiting on all procs') if $DEBUG;
+    my $waited_for = reapall();
 
     my $pid;
     do {
@@ -516,3 +520,37 @@ sub __run_productive_waitpid_code {
 }
 
 1;
+
+
+=head1 NAME
+
+Forks::Super::Wait
+
+=head1 VERSION
+
+0.74
+
+=head1 DESCRIPTION
+
+C<Forks::Super::Wait> is part of the L<Forks::Super|Forks::Super> distribution.
+The function and variables in this module manage the background processes
+at the end of their life cycle.
+
+There should not be much reason for a L<Forks::Super|Forks::Super> user to
+call functions or manipulate variables in this module directly.
+
+=head1 AUTHOR
+
+Marty O'Brien, E<lt>mob@cpan.orgE<gt>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2009-2015, Marty O'Brien.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.8 or,
+at your option, any later version of Perl 5 you may have available.
+
+See http://dev.perl.org/licenses/ for more information.
+
+=cut
